import pytest
from openai import OpenAI

from air.api.vector_db import BaseVectorDB, VectorDBConfig


@pytest.fixture()
def mock_openai_client():
    """
    Automatically mock 'air.api.vector_db.base_vectordb.auth' module globally.
    """
    return OpenAI(api_key="test-api-key")


@pytest.fixture
def mock_vector_db_config() -> VectorDBConfig:
    """
    Fixture to mock vector db configuration
    """
    return VectorDBConfig(
        base_url="http://test-url.com",
        api_key="test-key",
        api_version="test-version",
        index="test-vectordb",
        embedding_column="text_vector",
        top_k=1,
        content_column=["text"],
    )


@pytest.fixture
def mock_vector_db(request) -> BaseVectorDB:
    """
    Fixture to mock BaseVectorDB class
    """
    vector_db_config = request.getfixturevalue("mock_vector_db_config")
    return BaseVectorDB(vector_db_config)


def test_init(request):
    """
    Function to test the initialization of BaseVectorDB
    """
    vector_db_config = request.getfixturevalue("mock_vector_db_config")
    vector_db = BaseVectorDB(vector_db_config)
    assert vector_db.url == "http://test-url.com"
    assert vector_db.api_key == "test-key"
    assert vector_db.api_version == "test-version"
    assert vector_db.index == "test-vectordb"
